==> igniteui-angular-charts-17.3.0.tgz: package/esm2015/lib/DetrendedPriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { DetrendedPriceOscillatorIndicatorStrategy } from "./DetrendedPriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let DetrendedPriceOscillatorIndicator = /*@__PURE__*/ (() => {
    class DetrendedPriceOscillatorIndicator extends StrategyBasedIndicator {
        bc() {
            return new DetrendedPriceOscillatorIndicator();
        }
        get_y0() {
            return new DetrendedPriceOscillatorIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return DetrendedPriceOscillatorIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get zl() {
            return typeGetValue(this.c(DetrendedPriceOscillatorIndicator.zm));
        }
        set zl(a) {
            this.h(DetrendedPriceOscillatorIndicator.zm, a);
        }
        y6() {
            return this.zl;
        }
        zf(a) {
            this.zl = a;
        }
    }
    DetrendedPriceOscillatorIndicator.$t = markType(DetrendedPriceOscillatorIndicator, 'DetrendedPriceOscillatorIndicator', StrategyBasedIndicator.$);
    DetrendedPriceOscillatorIndicator.zm = StrategyBasedIndicator.zi(20, DetrendedPriceOscillatorIndicator.$);
    return DetrendedPriceOscillatorIndicator;
})();

==> igniteui-angular-charts-18.0.0.tgz: package/esm2015/lib/DetrendedPriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { DetrendedPriceOscillatorIndicatorStrategy } from "./DetrendedPriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let DetrendedPriceOscillatorIndicator = /*@__PURE__*/ (() => {
    class DetrendedPriceOscillatorIndicator extends StrategyBasedIndicator {
        bb() {
            return new DetrendedPriceOscillatorIndicator();
        }
        get_aaa() {
            return new DetrendedPriceOscillatorIndicatorStrategy();
        }
        get aaa() {
            return this.get_aaa();
        }
        get_aan() {
            return DetrendedPriceOscillatorIndicator.$;
        }
        get aan() {
            return this.get_aan();
        }
        get aav() {
            return typeGetValue(this.c(DetrendedPriceOscillatorIndicator.aaw));
        }
        set aav(a) {
            this.h(DetrendedPriceOscillatorIndicator.aaw, a);
        }
        aag() {
            return this.aav;
        }
        aap(a) {
            this.aav = a;
        }
    }
    DetrendedPriceOscillatorIndicator.$t = markType(DetrendedPriceOscillatorIndicator, 'DetrendedPriceOscillatorIndicator', StrategyBasedIndicator.$);
    DetrendedPriceOscillatorIndicator.aaw = StrategyBasedIndicator.aas(20, DetrendedPriceOscillatorIndicator.$);
    return DetrendedPriceOscillatorIndicator;
})();
